@@ -5,13 +5,13 @@ our $AUTHORITY = 'cpan:GENE';
 
 use v5.36;
 
-our $VERSION = '0.0104';
+our $VERSION = '0.0105';
 
-use Moo;
 use strictures 2;
 use List::SomeUtils qw(first_index);
 use MIDI::Drummer::Tiny ();
 use MIDI::RtMidi::ScorePlayer ();
+use Moo;
 use Types::Standard qw(ArrayRef Num);
 use namespace::clean;
 
@@ -87,7 +87,7 @@ MIDI::RtController::Filter::Drums - RtController drum filters
 
 =head1 VERSION
 
-version 0.0104
+version 0.0105
 
 =head1 SYNOPSIS
 
@@ -96,11 +96,14 @@ version 0.0104
   use MIDI::RtController ();
   use MIDI::RtController::Filter::Drums ();
 
-  my $rtc = MIDI::RtController->new; # * input/output required
+  my $rtc = MIDI::RtController->new(
+    input  => 'keyboard',
+    output => 'usb',
+  );
 
-  my $rtf = MIDI::RtController::Filter::Drums->new(rtc => $rtc);
+  my $filter = MIDI::RtController::Filter::Drums->new(rtc => $rtc);
 
-  $rtc->add_filter('drums', note_on => $rtf->curry::drums);
+  $rtc->add_filter('drums', note_on => $filter->curry::drums);
 
   $rtc->run;
 
@@ -113,15 +116,15 @@ filter for the drums.
 
 =head2 rtc
 
-  $rtc = $rtf->rtc;
+  $rtc = $filter->rtc;
 
 The required L<MIDI::RtController> instance provided in the
 constructor.
 
 =head2 bars
 
-  $bars = $rtf->bars;
-  $rtf->bars($number);
+  $bars = $filter->bars;
+  $filter->bars($number);
 
 The number of measures to set for the drummer bars.
 
@@ -129,8 +132,8 @@ Default: C<1>
 
 =head2 bpm
 
-  $bpm = $rtf->bpm;
-  $rtf->bpm($number);
+  $bpm = $filter->bpm;
+  $filter->bpm($number);
 
 The beats per minute.
 
@@ -157,6 +160,14 @@ Play the drums.
 
 =head1 SEE ALSO
 
+The F<eg/*.pl> program(s) in this distribution
+
+L<MIDI::RtController::Filter::Tonal>
+
+L<MIDI::RtController::Filter::Math>
+
+L<MIDI::RtController::Filter::CC>
+
 L<List::SomeUtils>
 
 L<MIDI::Drummer::Tiny>
